@@ -60,12 +60,7 @@ def imopen(
         extension. This affects the order in which backends are considered, and
         when writing this may also influence the format used when encoding.
     format_hint : str
-        A format hint to help optimize plugin selection given as the format's
-        extension, e.g. ".png". This can speed up the selection process for
-        ImageResources that don't have an explicit extension, e.g. streams, or
-        for ImageResources where the extension does not match the resource's
-        content. If the ImageResource lacks an explicit extension, it will be
-        set to this format.
+        Deprecated. Use `extension` instead.
     legacy_mode : bool
         If true (default) use the v2 behavior when searching for a suitable
         plugin. This will ignore v3 plugins and will check ``plugin``
@@ -134,15 +129,11 @@ def imopen(
             def loader(request, **kwargs):
                 return config.plugin_class(request, **kwargs)
 
-        elif not legacy_mode:
+        else:
 
             def loader(request, **kwargs):
                 return plugin(request, **kwargs)
 
-        else:
-            request.finish()
-            raise ValueError("The `plugin` argument must be a string.")
-
         try:
             return loader(request, **kwargs)
         except InitializationError as class_specific:
@@ -170,10 +161,6 @@ def imopen(
             for plugin_name in candidate_format.priority:
                 config = known_plugins[plugin_name]
 
-                # v2 compatibility; delete in v3
-                if legacy_mode and not config.is_legacy:
-                    continue
-
                 try:
                     candidate_plugin = config.plugin_class
                 except ImportError:
@@ -199,10 +186,6 @@ def imopen(
             for plugin_name in candidate_format.priority:
                 config = known_plugins[plugin_name]
 
-                # v2 compatibility; delete in v3
-                if legacy_mode and not config.is_legacy:
-                    continue
-
                 try:
                     candidate_plugin = config.plugin_class
                 except ImportError:
@@ -247,11 +230,6 @@ def imopen(
 
     # fallback option: try all plugins
     for config in known_plugins.values():
-        # Note: for v2 compatibility
-        # this branch can be removed in ImageIO v3.0
-        if legacy_mode and not config.is_legacy:
-            continue
-
         # each plugin gets its own request
         request = Request(uri, io_mode, format_hint=format_hint)
 
